def myFun(param, level=0):
	if isinstance(param, list):
		for item in param:
			if isinstance(param,list):
				myFun(item, level+1)
			else:
                                for item_level in range(level):
                                        print("\t",end='')
                                print(item)
	else:
		print(param)




from distutils.core import setup

setup(
    name        = "tanbing1011",
    version     = "1.1.0",
    py_modules  = ['tanbing1011'],
    author      = "tanbing",
    author_email= "bing0ye@163.com",
    url         = "www.baidu.com",
    description = "Hello Python",
    )
